Index: /trunk/src/VBox/Main/ExtPackManagerImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/ExtPackManagerImpl.cpp	(revision 35012)
+++ /trunk/src/VBox/Main/ExtPackManagerImpl.cpp	(revision 35013)
@@ -262,5 +262,5 @@
 
 /**
  * Protected helper that formats the strExtPackFile value.
  *
  * @returns S_OK
@@ -272,5 +272,5 @@
     va_list va;
     va_start(va, a_pszWhyFmt);
-    m->strExtPackFile.printfV(a_pszWhyFmt, va);
+    m->strWhyUnusable.printfV(a_pszWhyFmt, va);
     va_end(va);
     return S_OK;
@@ -262,5 +262,5 @@
 
 /**
- * Protected helper that formats the strExtPackFile value.
+ * Protected helper that formats the strWhyUnusable value.
  *
  * @returns S_OK
